aboutsummaryrefslogtreecommitdiff
path: root/backends/gp32/gp32.h
diff options
context:
space:
mode:
authorMax Horn2004-02-28 12:58:13 +0000
committerMax Horn2004-02-28 12:58:13 +0000
commitc6752cccf5186fb04c97e2bb4a64c52fc9447073 (patch)
tree91f3f0264b1542a839cc3504b52603a8034547cb /backends/gp32/gp32.h
parent56102a1d02925abbe9fc0504751de1a270a34ff3 (diff)
downloadscummvm-rg350-c6752cccf5186fb04c97e2bb4a64c52fc9447073.tar.gz
scummvm-rg350-c6752cccf5186fb04c97e2bb4a64c52fc9447073.tar.bz2
scummvm-rg350-c6752cccf5186fb04c97e2bb4a64c52fc9447073.zip
renamed more OSystem methods to follow our naming scheme; renamed NewGuiColor to OverlayColor; fixed some calls to error() in the SDL backend
svn-id: r13087
Diffstat (limited to 'backends/gp32/gp32.h')
-rw-r--r--backends/gp32/gp32.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/backends/gp32/gp32.h b/backends/gp32/gp32.h
index 2b692f0493..435072626d 100644
--- a/backends/gp32/gp32.h
+++ b/backends/gp32/gp32.h
@@ -35,7 +35,7 @@
class OSystem_GP32 : public OSystem {
public:
// Set colors of the palette
- void set_palette(const byte *colors, uint start, uint num);
+ void setPalette(const byte *colors, uint start, uint num);
// Set the size of the video bitmap.
// Typically, 320x200
@@ -52,7 +52,7 @@ public:
void move_screen(int dx, int dy, int height);
// Update the dirty areas of the screen
- void update_screen();
+ void updateScreen();
// Either show or hide the mouse cursor
bool show_mouse(bool visible);
@@ -103,10 +103,10 @@ public:
void set_timer(TimerProc callback, int timer);
// Mutex handling
- OSystem::MutexRef create_mutex();
- void lock_mutex(MutexRef mutex);
- void unlock_mutex(MutexRef mutex);
- void delete_mutex(MutexRef mutex);
+ OSystem::MutexRef createMutex();
+ void lockMutex(MutexRef mutex);
+ void unlockMutex(MutexRef mutex);
+ void deleteMutex(MutexRef mutex);
// Quit
void quit();
@@ -149,7 +149,7 @@ private:
DF_UPDATE_EXPAND_1_PIXEL = 1 << 3
};
- bool _forceFull; // Force full redraw on next update_screen
+ bool _forceFull; // Force full redraw on next updateScreen
int _scaleFactor;
int _mode;
bool _full_screen;